@@ -22,7 +22,7 @@
     <name>FileAssocDialog</name>
     <message>
         <source>Please enter the new extension:</source>
-        <translation>Bitte neue Erweiterung eingeben:</translation>
+        <translation>Bitte die neue Erweiterung eingeben:</translation>
     </message>
     <message>
         <source>Create new extension</source>
@@ -83,14 +83,6 @@
         <source>Parental Control PIN</source>
         <translation>Kindersicherungs-PIN</translation>
     </message>
-    <message>
-        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier. If you don&apos;t want to be bothered by PC dialogs, please set it to be blank.</source>
-        <translation type="obsolete">PIN zur Einstellung des aktuellen Kindersicherungs-Levels. Es ist einfacher, wenn Sie für die PIN nur Zahlen verwenden. Lassen Sie den Wert leer, um nicht von PC-Dialogen gestört zu werden.</translation>
-    </message>
-    <message>
-        <source>Aggresive Parental Control</source>
-        <translation>Aggressive Kindersicherung</translation>
-    </message>
     <message>
         <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
         <translation>Falls gesetzt, können Sie nicht mehr zu diesem Menü zurückkehren und die PIN neu setzen, ohne die aktuelle PIN einzugeben. Sie wurden gewarnt.</translation>
@@ -111,17 +103,13 @@
         <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
         <translation>Falls gesetzt, so werden im Videolisten-Menü alle relevanten Dateien im MythVideo Verzeichnis und darunter, unabhängig davon ob sie eingelesen wurden oder nicht, angezeigt.</translation>
     </message>
-    <message>
-        <source>This is the command used for any file that the extension is not specifically defined.</source>
-        <translation type="obsolete">Dies ist der Befehl, der für alle Dateien mit nicht speziell definierten Erweiterungen verwendet wird.</translation>
-    </message>
     <message>
         <source>General Settings</source>
-        <translation>Allgemeine Einstellungen</translation>
+        <translation>Grundeinstellungen</translation>
     </message>
     <message>
         <source>Player Settings</source>
-        <translation>Wiedergabe Einstellungen</translation>
+        <translation>Wiedergabe</translation>
     </message>
     <message>
         <source>Parental Pin:</source>
@@ -153,11 +141,11 @@
     </message>
     <message>
         <source>Unknown Rating</source>
-        <translation>Unbekannte Beschränkung</translation>
+        <translation>Unbekannte Altersfreigabe</translation>
     </message>
     <message>
         <source>Default Player</source>
-        <translation>Abspielkommando</translation>
+        <translation>Abspielbefehl</translation>
     </message>
     <message>
         <source>Newly scanned files are browsable by default</source>
@@ -167,10 +155,6 @@
         <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
         <translation>Falls gesetzt, werden neue Dateien im Videomanager als freigegeben markiert und erscheinen im &apos;Browse&apos; Menü.</translation>
     </message>
-    <message>
-        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos; or &apos;MythXine&apos;.</source>
-        <translation>Dieser Befehl wird für alle Dateien verwendet für deren Erweiterung nichts anderes definiert wurde. Sie können auch den Namen eines MythTV Moduls wie z.B. &apos;Internal&apos; oder &apos;MythXine&apos; angeben.</translation>
-    </message>
     <message>
         <source>New category</source>
         <translation>Neue Kategorie</translation>
@@ -217,6 +201,62 @@
         <translation>Für diesen Film existiert ein Titelbild aber MythVideo konnte es nicht in einer angemessenen Zeitspanne laden.
 </translation>
     </message>
+    <message>
+        <source>Default View</source>
+        <translation>Standardansicht</translation>
+    </message>
+    <message>
+        <source>Gallery</source>
+        <translation>Galerie</translation>
+    </message>
+    <message>
+        <source>Browser</source>
+        <translation>Browser</translation>
+    </message>
+    <message>
+        <source>Listings</source>
+        <translation>Übersicht</translation>
+    </message>
+    <message>
+        <source>Aggressive Parental Control</source>
+        <translation>Aggressive Kindersicherung</translation>
+    </message>
+    <message>
+        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
+        <translation>Dieser Befehl wird für alle Dateien verwendet, für deren Erweiterung nichts anderes festgelegt wurde. Sie können auch den Namen eines MythTV Plugins eingeben, z.B. &apos;Internal&apos;.</translation>
+    </message>
+    <message>
+        <source>Rows to display</source>
+        <translation>Wieviele Zeilen anzeigen</translation>
+    </message>
+    <message>
+        <source>Columns to display</source>
+        <translation>Wieviele Spalten anzeigen</translation>
+    </message>
+    <message>
+        <source>Show title below thumbnails</source>
+        <translation>Titel unter den Miniaturbildern zeigen</translation>
+    </message>
+    <message>
+        <source>If set, the additional text will make the thumbnails smaller.</source>
+        <translation>Falls gesetzt, werden durch den zusätzlichen Text die Miniaturbilder kleiner.</translation>
+    </message>
+    <message>
+        <source>Maintain aspect ratio of thumbnails</source>
+        <translation>Seitenverhältnis der Miniaturbilder beibehalten</translation>
+    </message>
+    <message>
+        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
+        <translation>Falls gesetzt, behalten die Miniaturbilder ihr Seitenverhältnis bei. Ansonsten werden sie passend zum Hintergrundsymbol skaliert.</translation>
+    </message>
+    <message>
+        <source>Video Gallery</source>
+        <translation>Videogalerie</translation>
+    </message>
+    <message>
+        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
+        <translation>Die Standardansicht für MythVideo. Andere Ansichten können durch drücken der &apos;MENU&apos;-Taste im Popup-Fenster ausgewählt werden.</translation>
+    </message>
 </context>
 <context>
     <name>ThemeUI</name>
@@ -260,14 +300,6 @@
         <source>IMDB Num.:</source>
         <translation>IMDB-Nr.:</translation>
     </message>
-    <message>
-        <source>0-9: Edit</source>
-        <translation type="obsolete">0-9: Editieren</translation>
-    </message>
-    <message>
-        <source>Menu/Info: Manual IMDB</source>
-        <translation type="obsolete">Menu/Info: IMDB manuell</translation>
-    </message>
     <message>
         <source>retrieving data...</source>
         <translation>Hole Daten...</translation>
@@ -288,10 +320,6 @@
         <source>No Videos Found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
-    <message>
-        <source>Use the left and right arrows</source>
-        <translation type="obsolete">Verwende Links-/Rechts-Pfeiltasten</translation>
-    </message>
     <message>
         <source>Directed by</source>
         <translation>Regie:</translation>
@@ -326,7 +354,7 @@
     </message>
     <message>
         <source>Edit Video Information</source>
-        <translation>Video-Informationen editieren</translation>
+        <translation>Video-Informationen bearbeiten</translation>
     </message>
     <message>
         <source>Name:</source>
@@ -338,11 +366,11 @@
     </message>
     <message>
         <source>File to Always Play Next:</source>
-        <translation>Datei immer anschließend spielen:</translation>
+        <translation>Anschließend abspielen:</translation>
     </message>
     <message>
         <source>Include while Browsing:</source>
-        <translation>Beim Listen berücksichtigen:</translation>
+        <translation>Beim browsen berücksichtigen:</translation>
     </message>
     <message>
         <source>Cover Art:</source>
@@ -358,19 +386,19 @@
     </message>
     <message>
         <source>1</source>
-        <translation type="unfinished">1</translation>
+        <translation>1</translation>
     </message>
     <message>
         <source>PL </source>
-        <translation type="unfinished"></translation>
+        <translation>PL</translation>
     </message>
     <message>
         <source>Category:</source>
-        <translation>Kategorie :</translation>
+        <translation>Kategorie:</translation>
     </message>
     <message>
         <source>Filters video list</source>
-        <translation type="unfinished"></translation>
+        <translation>Filtert die Videoliste</translation>
     </message>
     <message>
         <source>Category :</source>
@@ -390,7 +418,7 @@
     </message>
     <message>
         <source>Runtime :</source>
-        <translation>Spieldauer :</translation>
+        <translation>Laufzeit :</translation>
     </message>
     <message>
         <source>User Rating :</source>
@@ -410,23 +438,11 @@
     </message>
     <message>
         <source>SELECT: Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>SELECT: Bearbeiten</translation>
     </message>
     <message>
         <source></source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>MENU: Options</source>
-        <translation>MENÜ: Optionen</translation>
-    </message>
-    <message>
-        <source>Up/Down, Page Up/Down - Browse</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Menu - Options</source>
-        <translation>Menü - Optionen</translation>
+        <translation></translation>
     </message>
     <message>
         <source>Parental</source>
@@ -442,19 +458,27 @@
     </message>
     <message>
         <source>Runtime</source>
-        <translation>Spieldauer</translation>
+        <translation>Laufzeit</translation>
     </message>
     <message>
         <source>User Rating</source>
         <translation>Bewertung</translation>
     </message>
+    <message>
+        <source>INFO - Action Menu</source>
+        <translation>INFO - Aktionenmenü</translation>
+    </message>
+    <message>
+        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
+        <translation>Auf/Ab, Seite Auf/Ab: Browse   MENÜ: Optionen   INFO: Aktionenmenü</translation>
+    </message>
+    <message>
+        <source>Play File After This:</source>
+        <translation>Anschließend abspielen:</translation>
+    </message>
 </context>
 <context>
     <name>VideoBrowser</name>
-    <message>
-        <source>Parental Pin:</source>
-        <translation>Kindersicherungs-PIN:</translation>
-    </message>
     <message>
         <source>%1 of %2</source>
         <translation>%1 von %2</translation>
@@ -472,44 +496,117 @@
         <translation>Minuten</translation>
     </message>
     <message>
-        <source>Ok</source>
-        <translation>Ok</translation>
+        <source>Watch This Video</source>
+        <translation>Film ansehen</translation>
+    </message>
+    <message>
+        <source>View Full Plot</source>
+        <translation>Vollst. Beschreibung zeigen</translation>
+    </message>
+    <message>
+        <source>Filter Display</source>
+        <translation>Anzeige filtern</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
+    </message>
+</context>
+<context>
+    <name>VideoDialog</name>
+    <message>
+        <source>Switch to Browse View</source>
+        <translation>Zur Browse-Ansicht wechseln</translation>
+    </message>
+    <message>
+        <source>Switch to Gallery View</source>
+        <translation>Zur Galerie-Ansicht wechseln</translation>
+    </message>
+    <message>
+        <source>Switch to List View</source>
+        <translation>Zur Übersichts-Ansicht wechseln</translation>
     </message>
     <message>
         <source>Select action</source>
         <translation>Aktion wählen</translation>
     </message>
+    <message>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <source>Parental Pin:</source>
+        <translation>Kindersicherungs-PIN:</translation>
+    </message>
+</context>
+<context>
+    <name>VideoFilterDialog</name>
+    <message>
+        <source>Result of this filter : %1 video(s)</source>
+        <translation>Ergebnis für diesen Filter: %1 Video(s)</translation>
+    </message>
+    <message>
+        <source>Result of this filter : No Videos</source>
+        <translation>Ergebnis für diesen Filter: Keine Videos</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>Unbekannt</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>Minuten</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Alle</translation>
+    </message>
+    <message>
+        <source>Save as default</source>
+        <translation>Als Standard abspeichern</translation>
+    </message>
+    <message>
+        <source>Done</source>
+        <translation>Fertig</translation>
+    </message>
+</context>
+<context>
+    <name>VideoGallery</name>
+    <message>
+        <source>Filter Display</source>
+        <translation>Anzeige filtern</translation>
+    </message>
     <message>
         <source>Watch This Video</source>
         <translation>Film ansehen</translation>
     </message>
     <message>
         <source>View Full Plot</source>
-        <translation>Kompl. Beschreibung ansehen</translation>
+        <translation>Vollst. Beschreibung zeigen</translation>
     </message>
     <message>
-        <source>Filter Display</source>
-        <translation type="unfinished"></translation>
+        <source>View Details</source>
+        <translation>Einzelheiten zeigen</translation>
     </message>
     <message>
-        <source>Switch to Video Listings</source>
-        <translation>Zur Videoliste wechseln</translation>
+        <source>Plain View</source>
+        <translation>Einfache Ansicht</translation>
+    </message>
+    <message>
+        <source>Folder View</source>
+        <translation>Verzeichnisansicht</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
     </message>
 </context>
 <context>
     <name>VideoManager</name>
-    <message>
-        <source>Sorry there were no matches for the title</source>
-        <translation type="obsolete">Leider keine Treffer für den Titel</translation>
-    </message>
     <message>
         <source>Manually Enter IMDB #</source>
         <translation>Manuelle Eingabe der IMDB-Nr.</translation>
     </message>
-    <message>
-        <source>Reset Entry</source>
-        <translation type="obsolete">Eintrag zurücksetzen</translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation>Abbrechen</translation>
@@ -572,13 +669,24 @@
     </message>
     <message>
         <source>Filter Display</source>
-        <translation type="unfinished"></translation>
+        <translation>Anzeige filtern</translation>
     </message>
     <message>
         <source>Delete this file?</source>
         <translation>Diese Datei löschen?</translation>
     </message>
 </context>
+<context>
+    <name>VideoSelected</name>
+    <message>
+        <source>No rating available.</source>
+        <translation>Keine Altersfreigabe vorhanden.</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>Minuten</translation>
+    </message>
+</context>
 <context>
     <name>VideoTree</name>
     <message>
@@ -589,5 +697,37 @@
         <source>No files found</source>
         <translation>Keine Dateien gefunden</translation>
     </message>
+    <message>
+        <source>Select action</source>
+        <translation>Aktion wählen</translation>
+    </message>
+    <message>
+        <source>Watch This Video</source>
+        <translation>Film ansehen</translation>
+    </message>
+    <message>
+        <source>View Full Plot</source>
+        <translation>vollst. Beschreibung zeigen</translation>
+    </message>
+    <message>
+        <source>Filter Display</source>
+        <translation>Anzeige filtern</translation>
+    </message>
+    <message>
+        <source>Switch to Browse View</source>
+        <translation>Zur Browse-Ansicht wechseln</translation>
+    </message>
+    <message>
+        <source>Switch to Gallery View</source>
+        <translation>Zur Galerie-Ansicht wechseln</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
 </context>
 </TS>
