@@ -83,10 +83,6 @@
         <source>Parental Control PIN</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Aggresive Parental Control</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
         <translation type="unfinished"></translation>
@@ -159,10 +155,6 @@
         <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos; or &apos;MythXine&apos;.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>New category</source>
         <translation type="unfinished"></translation>
@@ -208,6 +200,62 @@
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Default View</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Gallery</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Browser</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Listings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Aggressive Parental Control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rows to display</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Columns to display</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show title below thumbnails</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, the additional text will make the thumbnails smaller.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Maintain aspect ratio of thumbnails</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video Gallery</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ThemeUI</name>
@@ -399,18 +447,6 @@
         <source></source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>MENU: Options</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Up/Down, Page Up/Down - Browse</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Menu - Options</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Parental</source>
         <translation type="unfinished"></translation>
@@ -431,13 +467,21 @@
         <source>User Rating</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>INFO - Action Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Play File After This:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VideoBrowser</name>
-    <message>
-        <source>Parental Pin:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>%1 of %2</source>
         <translation type="unfinished"></translation>
@@ -454,14 +498,6 @@
         <source>minutes</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Ok</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Select action</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Watch This Video</source>
         <translation type="unfinished"></translation>
@@ -475,7 +511,96 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Switch to Video Listings</source>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>VideoDialog</name>
+    <message>
+        <source>Switch to Browse View</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Switch to Gallery View</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Switch to List View</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Parental Pin:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>VideoFilterDialog</name>
+    <message>
+        <source>Result of this filter : %1 video(s)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Result of this filter : No Videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save as default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Done</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>VideoGallery</name>
+    <message>
+        <source>Filter Display</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Watch This Video</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>View Full Plot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>View Details</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plain View</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Folder View</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -554,6 +679,17 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>VideoSelected</name>
+    <message>
+        <source>No rating available.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>VideoTree</name>
     <message>
@@ -564,5 +700,37 @@
         <source>No files found</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Watch This Video</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>View Full Plot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter Display</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Switch to Browse View</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Switch to Gallery View</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
