@@ -92,7 +92,7 @@
     </message>
     <message>
         <source>Aggresive Parental Control</source>
-        <translation>積極的な再生制限制御</translation>
+        <translation type="obsolete">積極的な再生制限制御</translation>
     </message>
     <message>
         <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
@@ -108,11 +108,11 @@
     </message>
     <message>
         <source>Video List browses files</source>
-        <translation type="unfinished"></translation>
+        <translation>見えるファイルを表示する</translation>
     </message>
     <message>
         <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
-        <translation type="unfinished"></translation>
+        <translation>これをセットすると、MythVideoの開始ディレクトリで関連の有るファイルをスキャンされてなくても表示します。</translation>
     </message>
     <message>
         <source>This is the command used for any file that the extension is not specifically defined.</source>
@@ -170,10 +170,6 @@
         <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
         <translation>新しく検索されたファイルをビデオマネージャーで表示可能のマークをつける。</translation>
     </message>
-    <message>
-        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos; or &apos;MythXine&apos;.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>New category</source>
         <translation>新カテゴリー</translation>
@@ -184,11 +180,11 @@
     </message>
     <message>
         <source>Command to search for movie listings</source>
-        <translation type="unfinished"></translation>
+        <translation>映画リストの検索コマンド</translation>
     </message>
     <message>
         <source>This command must be executable by the user running MythVideo.</source>
-        <translation type="unfinished"></translation>
+        <translation>MythVideoの実行ユーザーが実行できるコマンドを指定してください。</translation>
     </message>
     <message>
         <source>Command to search for movie posters</source>
@@ -196,7 +192,7 @@
     </message>
     <message>
         <source>Command to extract data for movies</source>
-        <translation type="unfinished"></translation>
+        <translation>映画データの解凍コマンド</translation>
     </message>
     <message>
         <source>Directory that holds movie posters</source>
@@ -220,6 +216,62 @@
         <translation>この映画のポスターは存在しますがMythTVは時間内に検索できませんでした。
 </translation>
     </message>
+    <message>
+        <source>Default View</source>
+        <translation>規定のビュー</translation>
+    </message>
+    <message>
+        <source>Gallery</source>
+        <translation>ギャラリー</translation>
+    </message>
+    <message>
+        <source>Browser</source>
+        <translation>ブラウザ</translation>
+    </message>
+    <message>
+        <source>Listings</source>
+        <translation>リスト</translation>
+    </message>
+    <message>
+        <source>Aggressive Parental Control</source>
+        <translation>積極的な再生制御</translation>
+    </message>
+    <message>
+        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rows to display</source>
+        <translation>表示行</translation>
+    </message>
+    <message>
+        <source>Columns to display</source>
+        <translation>表示列</translation>
+    </message>
+    <message>
+        <source>Show title below thumbnails</source>
+        <translation>サムネイルのしたにタイトルを表示</translation>
+    </message>
+    <message>
+        <source>If set, the additional text will make the thumbnails smaller.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Maintain aspect ratio of thumbnails</source>
+        <translation>サムネイルのアスペクトレシオを保持する</translation>
+    </message>
+    <message>
+        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video Gallery</source>
+        <translation>ビデオギャラリー</translation>
+    </message>
+    <message>
+        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
+        <translation>MythVideoのデフォルトビュー。他のビューはMENUキーを押して出るポップアップから選択できます。</translation>
+    </message>
 </context>
 <context>
     <name>ThemeUI</name>
@@ -401,7 +453,7 @@
     </message>
     <message>
         <source>User Rating :</source>
-        <translation>ユーザー格付け:</translation>
+        <translation>ユーザー格付:</translation>
     </message>
     <message>
         <source>Browse :</source>
@@ -425,15 +477,15 @@
     </message>
     <message>
         <source>MENU: Options</source>
-        <translation>メニュー: オプション</translation>
+        <translation type="obsolete">メニュー: オプション</translation>
     </message>
     <message>
         <source>Up/Down, Page Up/Down - Browse</source>
-        <translation>Up/Down, Page Up/Down - 表示</translation>
+        <translation type="obsolete">Up/Down, Page Up/Down - 表示</translation>
     </message>
     <message>
         <source>Menu - Options</source>
-        <translation>メニュー - オプション</translation>
+        <translation type="obsolete">メニュー - オプション</translation>
     </message>
     <message>
         <source>Parental</source>
@@ -455,12 +507,24 @@
         <source>User Rating</source>
         <translation>ユーザー格付け</translation>
     </message>
+    <message>
+        <source>INFO - Action Menu</source>
+        <translation>INFO - アクションメニュー</translation>
+    </message>
+    <message>
+        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
+        <translation>Up/Down, Page Up/Down: 移動   MENU: オプション   INFO: アクションメニュー</translation>
+    </message>
+    <message>
+        <source>Play File After This:</source>
+        <translation>このファイルの後に再生:</translation>
+    </message>
 </context>
 <context>
     <name>VideoBrowser</name>
     <message>
         <source>Parental Pin:</source>
-        <translation>再生制限ピン:</translation>
+        <translation type="obsolete">再生制限ピン:</translation>
     </message>
     <message>
         <source>%1 of %2</source>
@@ -478,13 +542,9 @@
         <source>minutes</source>
         <translation>分</translation>
     </message>
-    <message>
-        <source>Ok</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Select action</source>
-        <translation>動作選択</translation>
+        <translation type="obsolete">動作選択</translation>
     </message>
     <message>
         <source>Watch This Video</source>
@@ -500,7 +560,100 @@
     </message>
     <message>
         <source>Switch to Video Listings</source>
-        <translation>ビデオリストに切替える</translation>
+        <translation type="obsolete">ビデオリストに切替える</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>キャンセル</translation>
+    </message>
+</context>
+<context>
+    <name>VideoDialog</name>
+    <message>
+        <source>Switch to Browse View</source>
+        <translation>ブラウズビューに切替え</translation>
+    </message>
+    <message>
+        <source>Switch to Gallery View</source>
+        <translation>ギャラリービューに切替え</translation>
+    </message>
+    <message>
+        <source>Switch to List View</source>
+        <translation>リストビューに切替え</translation>
+    </message>
+    <message>
+        <source>Select action</source>
+        <translation>動作選択</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>はい</translation>
+    </message>
+    <message>
+        <source>Parental Pin:</source>
+        <translation>再生制限ピン:</translation>
+    </message>
+</context>
+<context>
+    <name>VideoFilterDialog</name>
+    <message>
+        <source>Result of this filter : %1 video(s)</source>
+        <translation>このフィルタの結果 : %1 個</translation>
+    </message>
+    <message>
+        <source>Result of this filter : No Videos</source>
+        <translation>このフィルタの結果 : 該当無し</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>不明</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>分</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>全て</translation>
+    </message>
+    <message>
+        <source>Save as default</source>
+        <translation>規定で保存</translation>
+    </message>
+    <message>
+        <source>Done</source>
+        <translation>終了</translation>
+    </message>
+</context>
+<context>
+    <name>VideoGallery</name>
+    <message>
+        <source>Filter Display</source>
+        <translation>絞りこみ表示</translation>
+    </message>
+    <message>
+        <source>Watch This Video</source>
+        <translation>このビデオを見る</translation>
+    </message>
+    <message>
+        <source>View Full Plot</source>
+        <translation>全ての粗筋を表示する</translation>
+    </message>
+    <message>
+        <source>View Details</source>
+        <translation>詳細を表示する</translation>
+    </message>
+    <message>
+        <source>Plain View</source>
+        <translation>プレインビュー</translation>
+    </message>
+    <message>
+        <source>Folder View</source>
+        <translation>フォルダービュー</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>キャンセル</translation>
     </message>
 </context>
 <context>
@@ -586,6 +739,17 @@
         <translation>このファイルを削除しますか?</translation>
     </message>
 </context>
+<context>
+    <name>VideoSelected</name>
+    <message>
+        <source>No rating available.</source>
+        <translation>レイティングは使用できません.</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>分</translation>
+    </message>
+</context>
 <context>
     <name>VideoTree</name>
     <message>
@@ -596,5 +760,37 @@
         <source>No files found</source>
         <translation>ファイルを見つけられませんでした</translation>
     </message>
+    <message>
+        <source>Select action</source>
+        <translation>動作選択</translation>
+    </message>
+    <message>
+        <source>Watch This Video</source>
+        <translation>このビデオを見る</translation>
+    </message>
+    <message>
+        <source>View Full Plot</source>
+        <translation>全ての粗筋を表示する</translation>
+    </message>
+    <message>
+        <source>Filter Display</source>
+        <translation>絞りこみ表示</translation>
+    </message>
+    <message>
+        <source>Switch to Browse View</source>
+        <translation>ブラウズビューに切替え</translation>
+    </message>
+    <message>
+        <source>Switch to Gallery View</source>
+        <translation>ギャラリービューに切替え</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>キャンセル</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>はい</translation>
+    </message>
 </context>
 </TS>
