@@ -3,209 +3,263 @@
     <name>EditMetadataDialog</name>
     <message>
         <source>Level %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Niveau %1</translation>
     </message>
     <message>
         <source>None</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen Cover</translation>
     </message>
     <message>
         <source>Done</source>
-        <translation type="unfinished"></translation>
+        <translation>Klaar</translation>
     </message>
 </context>
 <context>
     <name>FileAssocDialog</name>
     <message>
         <source>Please enter the new extension:</source>
-        <translation type="unfinished"></translation>
+        <translation>Geef nieuwe extensie:</translation>
     </message>
     <message>
         <source>Create new extension</source>
-        <translation type="unfinished"></translation>
+        <translation>Maak nieuwe extensie</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Annuleer</translation>
     </message>
     <message>
         <source>Done</source>
-        <translation type="unfinished"></translation>
+        <translation>Klaar</translation>
     </message>
     <message>
         <source>New</source>
-        <translation type="unfinished"></translation>
+        <translation>Nieuw</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Wis</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <source>Directory that holds videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Map voor videobestanden</translation>
     </message>
     <message>
         <source>This directory must exist, and the user running MythVideo only needs to have read permission to the directory.</source>
-        <translation type="unfinished"></translation>
+        <translation>Deze map moet bestaan en de gebruiker moet enkel leesbevoegdheid voor deze map hebben.</translation>
     </message>
     <message>
         <source>Starting Parental Level</source>
-        <translation type="unfinished"></translation>
+        <translation>Startniveau &apos;Parental Control&apos;</translation>
     </message>
     <message>
         <source>4 - Highest</source>
-        <translation type="unfinished"></translation>
+        <translation>4 -Hoogste</translation>
     </message>
     <message>
         <source>1 - Lowest</source>
-        <translation type="unfinished"></translation>
+        <translation>1 - Laagste</translation>
     </message>
     <message>
         <source>2</source>
-        <translation type="unfinished"></translation>
+        <translation>2</translation>
     </message>
     <message>
         <source>3</source>
-        <translation type="unfinished"></translation>
+        <translation>3</translation>
     </message>
     <message>
         <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
-        <translation type="unfinished"></translation>
+        <translation>Dit is het niveau waarin MythVideo start. Alle films met een gelijk of lager niveau worden standaard getoond. De &apos;Parental Control&apos; PIN kan best zo ingesteld worden dat het niveau zo weinig mogelijk veranderd moet worden.</translation>
     </message>
     <message>
         <source>Parental Control PIN</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Aggresive Parental Control</source>
-        <translation type="unfinished"></translation>
+        <translation>&apos;Parental Control&apos; PIN</translation>
     </message>
     <message>
         <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
-        <translation type="unfinished"></translation>
+        <translation>Indien ingesteld is het niet meer mogelijk naar dit scherm terug te keren om de PIN te resetten zonder de bestaande PIN in te voeren. U bent gewaarschuwd!</translation>
     </message>
     <message>
         <source>Show Unknown File Types</source>
-        <translation type="unfinished"></translation>
+        <translation>Toon onbekende bestandstypes</translation>
     </message>
     <message>
         <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
-        <translation type="unfinished"></translation>
+        <translation>Indien geselecteerd worden alle bestanden in de MythVideo-map getoond tenzij de extensie expliciet ingesteld werd op negeren.</translation>
     </message>
     <message>
         <source>Video List browses files</source>
-        <translation type="unfinished"></translation>
+        <translation>Film Lijst bladert bestanden</translation>
     </message>
     <message>
         <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
-        <translation type="unfinished"></translation>
+        <translation>Indien geselecteerd worden alle relevante bestanden in de MythVideo-map getoond. Gescand of niet.</translation>
     </message>
     <message>
         <source>General Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Algemene Instellingen</translation>
     </message>
     <message>
         <source>Player Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Instellingen voor het Afspeelprogramma</translation>
     </message>
     <message>
         <source>Parental Pin:</source>
-        <translation type="unfinished"></translation>
+        <translation>&apos;Parental PIN&apos;:</translation>
     </message>
     <message>
         <source>Searching for video files</source>
-        <translation type="unfinished"></translation>
+        <translation>Zoek naar videobestanden</translation>
     </message>
     <message>
         <source>Updating video database</source>
-        <translation type="unfinished"></translation>
+        <translation>Bezig met bijwerken film-databank</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen Cover</translation>
     </message>
     <message>
         <source>Unknown</source>
-        <translation type="unfinished"></translation>
+        <translation>Onbekend</translation>
     </message>
     <message>
         <source>None</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen</translation>
     </message>
     <message>
         <source>NR</source>
-        <translation type="unfinished"></translation>
+        <translation>Niet Beoordeeld</translation>
     </message>
     <message>
         <source>Unknown Rating</source>
-        <translation type="unfinished"></translation>
+        <translation>Onbekende Beoordeling</translation>
     </message>
     <message>
         <source>Default Player</source>
-        <translation type="unfinished"></translation>
+        <translation>Standaard afspeelprogramma</translation>
     </message>
     <message>
         <source>Newly scanned files are browsable by default</source>
-        <translation type="unfinished"></translation>
+        <translation>Nieuw gescande bestanden worden standaard getoond</translation>
     </message>
     <message>
         <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos; or &apos;MythXine&apos;.</source>
-        <translation type="unfinished"></translation>
+        <translation>Indien geselecteerd worden nieuw gescande bestanden in de Video Manager gemarkeerd als &quot;bladerbaar&quot;.</translation>
     </message>
     <message>
         <source>New category</source>
-        <translation type="unfinished"></translation>
+        <translation>Nieuwe categorie</translation>
     </message>
     <message>
         <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier.</source>
-        <translation type="unfinished"></translation>
+        <translation>Deze PIN wordt gebruikt om het huidige &apos;Parental Control&apos; niveau te controleren. Als U dit wil instellen is het handig om enkel numerieke invoer te gebruiken.</translation>
     </message>
     <message>
         <source>Command to search for movie listings</source>
-        <translation type="unfinished"></translation>
+        <translation>Commando om te zoeken naar filminfo</translation>
     </message>
     <message>
         <source>This command must be executable by the user running MythVideo.</source>
-        <translation type="unfinished"></translation>
+        <translation>Dit commando moet uitgevoerd kunnen worden door de huidige gebruiker.</translation>
     </message>
     <message>
         <source>Command to search for movie posters</source>
-        <translation type="unfinished"></translation>
+        <translation>Commando om te zoeken naar filmcovers</translation>
     </message>
     <message>
         <source>Command to extract data for movies</source>
-        <translation type="unfinished"></translation>
+        <translation>Commando om filmdata te extraheren</translation>
     </message>
     <message>
         <source>Directory that holds movie posters</source>
-        <translation type="unfinished"></translation>
+        <translation>Map voor filmcovers</translation>
     </message>
     <message>
         <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
-        <translation type="unfinished"></translation>
+        <translation>Deze map moet bestaan en de gebruiker moet lees- en schrijfbevoegdheid hebben.</translation>
     </message>
     <message>
         <source>Video Manager</source>
-        <translation type="unfinished"></translation>
+        <translation>Video Manager</translation>
     </message>
     <message>
         <source>Could not retrieve poster</source>
-        <translation type="unfinished"></translation>
+        <translation>Kan cover niet downloaden</translation>
     </message>
     <message>
         <source>A movie poster exists for this movie but Myth could not retrieve it within a reasonable amount of time.
 </source>
+        <translation>Er bestaat een cover voor deze film maar die kan momenteel niet gedownload worden.
+
+</translation>
+    </message>
+    <message>
+        <source>Default View</source>
+        <translation>Standaard uiterlijk</translation>
+    </message>
+    <message>
+        <source>Gallery</source>
+        <translation>Gallerij</translation>
+    </message>
+    <message>
+        <source>Browser</source>
+        <translation>Browser</translation>
+    </message>
+    <message>
+        <source>Listings</source>
+        <translation>Lijst</translation>
+    </message>
+    <message>
+        <source>The defualt view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
+        <translation type="obsolete">Het standaard uiterlijk voor MythVideo. Een ander uiterlijk kiezen is mogelijk via het pop-up menu (MENU-toets).</translation>
+    </message>
+    <message>
+        <source>Aggressive Parental Control</source>
+        <translation>Agressieve &apos;Parental Control&apos;</translation>
+    </message>
+    <message>
+        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
+        <translation>Dit commando wordt gebruikt voor elk bestand met een niet gedefinieerde extensie. U kan ook de naam van een van de afspeel-plugins (bv. &apos;Internal&apos;) invoeren.</translation>
+    </message>
+    <message>
+        <source>Rows to display</source>
+        <translation>Getoond aantal rijen</translation>
+    </message>
+    <message>
+        <source>Columns to display</source>
+        <translation>Getoond aantal kolommen</translation>
+    </message>
+    <message>
+        <source>Show title below thumbnails</source>
+        <translation>Toon titel onder thumbnail</translation>
+    </message>
+    <message>
+        <source>If set, the additional text will make the thumbnails smaller.</source>
+        <translation>Indien geselecteerd zal de tekst de thumbnail kleiner maken.</translation>
+    </message>
+    <message>
+        <source>Maintain aspect ratio of thumbnails</source>
+        <translation>Verhouding van de thumbnails behouden</translation>
+    </message>
+    <message>
+        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
+        <translation>Indien geselecteerd zal de verhouding van de thumbnails behouden worden. Zo niet worden ze geschaald tot de afmeting van het achtergrondicoon.</translation>
+    </message>
+    <message>
+        <source>Video Gallery</source>
+        <translation>Video Gallerij</translation>
+    </message>
+    <message>
+        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -213,352 +267,496 @@
     <name>ThemeUI</name>
     <message>
         <source>Director:</source>
-        <translation type="unfinished"></translation>
+        <translation>Regisseur:</translation>
     </message>
     <message>
         <source>Year:</source>
-        <translation type="unfinished"></translation>
+        <translation>Jaar:</translation>
     </message>
     <message>
         <source>Rated:</source>
-        <translation type="unfinished"></translation>
+        <translation>Beoordeling:</translation>
     </message>
     <message>
         <source>Parental Level:</source>
-        <translation type="unfinished"></translation>
+        <translation>&apos;Parental Control&apos; Niveau:</translation>
     </message>
     <message>
         <source>Browsable:</source>
-        <translation type="unfinished"></translation>
+        <translation>Komt in lijst:</translation>
     </message>
     <message>
         <source>Runtime:</source>
-        <translation type="unfinished"></translation>
+        <translation>Speelduur:</translation>
     </message>
     <message>
         <source>Plot:</source>
-        <translation type="unfinished"></translation>
+        <translation>Inhoud:</translation>
     </message>
     <message>
         <source>Filename:</source>
-        <translation type="unfinished"></translation>
+        <translation>Bestandsnaam:</translation>
     </message>
     <message>
         <source>Cover File:</source>
-        <translation type="unfinished"></translation>
+        <translation>Cover bestand:</translation>
     </message>
     <message>
         <source>IMDB Num.:</source>
-        <translation type="unfinished"></translation>
+        <translation>IMDBnr.:</translation>
     </message>
     <message>
         <source>retrieving data...</source>
-        <translation type="unfinished"></translation>
+        <translation>downloaden van gegevens ...</translation>
     </message>
     <message>
         <source>[ looking for ]</source>
-        <translation type="unfinished"></translation>
+        <translation>[ zoeken naar ]</translation>
     </message>
     <message>
         <source>Enter IMDB #</source>
-        <translation type="unfinished"></translation>
+        <translation>Geef IMDBnr.</translation>
     </message>
     <message>
         <source>loading...</source>
-        <translation type="unfinished"></translation>
+        <translation>bezig met inlezen ...</translation>
     </message>
     <message>
         <source>No Videos Found</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen films gevonden</translation>
     </message>
     <message>
         <source>1</source>
-        <translation type="unfinished"></translation>
+        <translation>1</translation>
     </message>
     <message>
         <source>Directed by</source>
-        <translation type="unfinished"></translation>
+        <translation>Regie</translation>
     </message>
     <message>
         <source>File:</source>
-        <translation type="unfinished"></translation>
+        <translation>Bestand:</translation>
     </message>
     <message>
         <source>Player:</source>
-        <translation type="unfinished"></translation>
+        <translation>Afspeelprogramma:</translation>
     </message>
     <message>
         <source>PL </source>
-        <translation type="unfinished"></translation>
+        <translation>PL</translation>
     </message>
     <message>
         <source>MythVideo File Associations</source>
-        <translation type="unfinished"></translation>
+        <translation>Bestandstype koppelingen</translation>
     </message>
     <message>
         <source>Extension:</source>
-        <translation type="unfinished"></translation>
+        <translation>Extensie:</translation>
     </message>
     <message>
         <source>Command:</source>
-        <translation type="unfinished"></translation>
+        <translation>Commando:</translation>
     </message>
     <message>
         <source>Use default player:</source>
-        <translation type="unfinished"></translation>
+        <translation>Gebruik standaard afspeelprogramma:</translation>
     </message>
     <message>
         <source>Ignore:</source>
-        <translation type="unfinished"></translation>
+        <translation>Negeer:</translation>
     </message>
     <message>
         <source>Edit Video Information</source>
-        <translation type="unfinished"></translation>
+        <translation>Bewerk video gegevens:</translation>
     </message>
     <message>
         <source>Name:</source>
-        <translation type="unfinished"></translation>
+        <translation>Naam:</translation>
     </message>
     <message>
         <source>Parental Control:</source>
-        <translation type="unfinished"></translation>
+        <translation>&apos;Parental Control&apos;:</translation>
     </message>
     <message>
         <source>File to Always Play Next:</source>
-        <translation type="unfinished"></translation>
+        <translation>Bestand dat hierna dient afgespeeld:</translation>
     </message>
     <message>
         <source>Include while Browsing:</source>
-        <translation type="unfinished"></translation>
+        <translation>Weergeven in lijst:</translation>
     </message>
     <message>
         <source>Cover Art:</source>
-        <translation type="unfinished"></translation>
+        <translation>Cover:</translation>
     </message>
     <message>
         <source>Unique Player Command:</source>
-        <translation type="unfinished"></translation>
+        <translation>Uniek afspeelcommando:</translation>
     </message>
     <message>
         <source>/path/to/the/thing.jpg</source>
-        <translation type="unfinished"></translation>
+        <translation>/path/naar/afbeelding.jpg</translation>
     </message>
     <message>
         <source>Category:</source>
-        <translation type="unfinished"></translation>
+        <translation>Categorie:</translation>
     </message>
     <message>
         <source>Filters video list</source>
-        <translation type="unfinished"></translation>
+        <translation>Filter op filmoverzicht</translation>
     </message>
     <message>
         <source>Category :</source>
-        <translation type="unfinished"></translation>
+        <translation>Categorie :</translation>
     </message>
     <message>
         <source>Genre :</source>
-        <translation type="unfinished"></translation>
+        <translation>Genre :</translation>
     </message>
     <message>
         <source>Country :</source>
-        <translation type="unfinished"></translation>
+        <translation>Land :</translation>
     </message>
     <message>
         <source>Year :</source>
-        <translation type="unfinished"></translation>
+        <translation>Jaar :</translation>
     </message>
     <message>
         <source>Runtime :</source>
-        <translation type="unfinished"></translation>
+        <translation>Speeltijd :</translation>
     </message>
     <message>
         <source>User Rating :</source>
-        <translation type="unfinished"></translation>
+        <translation>Gebruikersbeoordeling :</translation>
     </message>
     <message>
         <source>Browse :</source>
-        <translation type="unfinished"></translation>
+        <translation>Bladeren :</translation>
     </message>
     <message>
         <source>Sort by :</source>
-        <translation type="unfinished"></translation>
+        <translation>Sorteren op :</translation>
     </message>
     <message>
         <source>Aucune video</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen video</translation>
     </message>
     <message>
         <source>SELECT: Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>SELECTEER: Bewerk</translation>
     </message>
     <message>
         <source></source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>MENU: Options</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">MENU: Opties</translation>
     </message>
     <message>
         <source>Up/Down, Page Up/Down - Browse</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Gebruik navigatietoetsen om te bladeren</translation>
     </message>
     <message>
         <source>Menu - Options</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Menu - Opties</translation>
     </message>
     <message>
         <source>Parental</source>
-        <translation type="unfinished"></translation>
+        <translation>&apos;Parental Control&apos;</translation>
     </message>
     <message>
         <source>Level</source>
-        <translation type="unfinished"></translation>
+        <translation>Niveau</translation>
     </message>
     <message>
         <source>Year</source>
-        <translation type="unfinished"></translation>
+        <translation>Jaar</translation>
     </message>
     <message>
         <source>Runtime</source>
-        <translation type="unfinished"></translation>
+        <translation>Speeltijd</translation>
     </message>
     <message>
         <source>User Rating</source>
-        <translation type="unfinished"></translation>
+        <translation>Gebruikersbeoordeling</translation>
+    </message>
+    <message>
+        <source>INFO - Action Menu</source>
+        <translation>INFO - Actie Menu</translation>
+    </message>
+    <message>
+        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
+        <translation>Omhoog/Omlaag, Pagina Op/Neer: Blader  MENU: Opties INFO: Actie Menu</translation>
+    </message>
+    <message>
+        <source>Play File After This:</source>
+        <translation>Speel vervolgens dit bestand:</translation>
     </message>
 </context>
 <context>
     <name>VideoBrowser</name>
-    <message>
-        <source>Parental Pin:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>%1 of %2</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 van %2</translation>
     </message>
     <message>
         <source>No Videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen Films</translation>
     </message>
     <message>
         <source>No rating available.</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen beoordeling beschikbaar.</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation type="unfinished"></translation>
+        <translation>minuten</translation>
     </message>
     <message>
         <source>Ok</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Ok</translation>
     </message>
     <message>
         <source>Select action</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Kies bewerking</translation>
     </message>
     <message>
         <source>Watch This Video</source>
-        <translation type="unfinished"></translation>
+        <translation>Bekijk deze Film</translation>
     </message>
     <message>
         <source>View Full Plot</source>
-        <translation type="unfinished"></translation>
+        <translation>Beschrijving Inhoud</translation>
     </message>
     <message>
         <source>Filter Display</source>
-        <translation type="unfinished"></translation>
+        <translation>Filter weergave</translation>
     </message>
     <message>
         <source>Switch to Video Listings</source>
+        <translation type="obsolete">Ga naar lijstweergave</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annuleer</translation>
+    </message>
+</context>
+<context>
+    <name>VideoDialog</name>
+    <message>
+        <source>Switch to Browse View</source>
+        <translation>Browsermodus</translation>
+    </message>
+    <message>
+        <source>Switch to Gallery View</source>
+        <translation>Gallerijmodus</translation>
+    </message>
+    <message>
+        <source>Switch to List View</source>
+        <translation>Lijstmodus</translation>
+    </message>
+    <message>
+        <source>Select action</source>
+        <translation>Kies actie</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <source>Parental Pin:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>VideoFilterDialog</name>
+    <message>
+        <source>Result of this filter : %1 video(s)</source>
+        <translation>Resultaat van deze filer : %1 video(s)</translation>
+    </message>
+    <message>
+        <source>Result of this filter : No Videos</source>
+        <translation>Resultaat van deze filer : Geen videos</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>Onbekend</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>minuten</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Alle</translation>
+    </message>
+    <message>
+        <source>Save as default</source>
+        <translation>Bewaar als standaard</translation>
+    </message>
+    <message>
+        <source>Done</source>
+        <translation>Klaar</translation>
+    </message>
+</context>
+<context>
+    <name>VideoGallery</name>
+    <message>
+        <source>Filter Display</source>
+        <translation>Gebruik Filterweergave</translation>
+    </message>
+    <message>
+        <source>Watch This Video</source>
+        <translation>Bekijk deze video</translation>
+    </message>
+    <message>
+        <source>View Full Plot</source>
+        <translation>Beschrijving Inhoud</translation>
+    </message>
+    <message>
+        <source>View Details</source>
+        <translation>Bekijk Details</translation>
+    </message>
+    <message>
+        <source>Plain View</source>
+        <translation>Overzicht alle folders</translation>
+    </message>
+    <message>
+        <source>Folder View</source>
+        <translation>Gebruik Folders</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annuleer</translation>
+    </message>
+</context>
 <context>
     <name>VideoManager</name>
     <message>
         <source>minutes</source>
-        <translation type="unfinished"></translation>
+        <translation>minuten</translation>
     </message>
     <message>
         <source>Yes</source>
-        <translation type="unfinished"></translation>
+        <translation>Ja</translation>
     </message>
     <message>
         <source>No</source>
-        <translation type="unfinished"></translation>
+        <translation>Neen</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen Cover</translation>
     </message>
     <message>
         <source>Unknown</source>
-        <translation type="unfinished"></translation>
+        <translation>Onbekend</translation>
     </message>
     <message>
         <source>None</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen</translation>
     </message>
     <message>
         <source>NR</source>
-        <translation type="unfinished"></translation>
+        <translation>Niet Beoordeeld</translation>
     </message>
     <message>
         <source>delete failed</source>
-        <translation type="unfinished"></translation>
+        <translation>wissen mislukt</translation>
     </message>
     <message>
         <source>Select action:</source>
-        <translation type="unfinished"></translation>
+        <translation>Kies bewerking:</translation>
     </message>
     <message>
         <source>Edit Metadata</source>
-        <translation type="unfinished"></translation>
+        <translation>Bewerk filmgegevens</translation>
     </message>
     <message>
         <source>Search IMDB</source>
-        <translation type="unfinished"></translation>
+        <translation>Zoek IMDB</translation>
     </message>
     <message>
         <source>Manually Enter IMDB #</source>
-        <translation type="unfinished"></translation>
+        <translation>Geef handmatig IMDBnr.</translation>
     </message>
     <message>
         <source>Reset Metadata</source>
-        <translation type="unfinished"></translation>
+        <translation>Wis gegevens</translation>
     </message>
     <message>
         <source>Toggle Browseable</source>
-        <translation type="unfinished"></translation>
+        <translation>In lijst ja/neen</translation>
     </message>
     <message>
         <source>Remove Video</source>
-        <translation type="unfinished"></translation>
+        <translation>Wis Film</translation>
     </message>
     <message>
         <source>Filter Display</source>
-        <translation type="unfinished"></translation>
+        <translation>Filter Weergave</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Annuleer</translation>
     </message>
     <message>
         <source>Delete this file?</source>
-        <translation type="unfinished"></translation>
+        <translation>Dit bestand wissen?</translation>
+    </message>
+</context>
+<context>
+    <name>VideoSelected</name>
+    <message>
+        <source>No rating available.</source>
+        <translation>Geen beoordeling beschikbaar.</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>minuten</translation>
     </message>
 </context>
 <context>
     <name>VideoTree</name>
     <message>
         <source>Parental Pin:</source>
-        <translation type="unfinished"></translation>
+        <translation>&apos;Parental Control&apos; PIN:</translation>
     </message>
     <message>
         <source>No files found</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen bestanden gevonden</translation>
+    </message>
+    <message>
+        <source>Select action</source>
+        <translation>Kies Actie</translation>
+    </message>
+    <message>
+        <source>Watch This Video</source>
+        <translation>Bekijk Film</translation>
+    </message>
+    <message>
+        <source>View Full Plot</source>
+        <translation>Beschrijving Inhoud</translation>
+    </message>
+    <message>
+        <source>Filter Display</source>
+        <translation>Filter Weergave</translation>
+    </message>
+    <message>
+        <source>Switch to Browse View</source>
+        <translation>Ga naar Browsermodus</translation>
+    </message>
+    <message>
+        <source>Switch to Gallery View</source>
+        <translation>Ga naar Gallerijmodus</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annuleer</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>Ok</translation>
     </message>
 </context>
 </TS>
