@@ -155,10 +155,6 @@
         <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
         <translation>Nyscannade filer i Video Manager kommer att markeras som bläddringsbara och kommer att synas i bläddra-menyn.</translation>
     </message>
-    <message>
-        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos; or &apos;MythXine&apos;.</source>
-        <translation type="obsolete">Detta är kommandot som används för att spela upp filer som har en filändelse som inte specifikt har associerats med en spelare. Du kan även skriva in namnet på en av avspelningspluginerna, exempelvis &apos;Internal&apos; eller &apos;MythXine&apos;.</translation>
-    </message>
     <message>
         <source>New category</source>
         <translation>Ny kategori</translation>
@@ -224,10 +220,6 @@
         <source>Listings</source>
         <translation>Listningar</translation>
     </message>
-    <message>
-        <source>The defualt view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
-        <translation>Standardvy för MythVideo. Andra vyer kan nås genom popup-menyn tillgänglig via MENY-knappen.</translation>
-    </message>
     <message>
         <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
         <translation>Detta är standardkommandot för uppspelning av filer. &apos;Internal&apos; använder Myth&apos;s egna uppspelningsmetod.</translation>
@@ -260,6 +252,10 @@
         <source>Video Gallery</source>
         <translation>Videogalleri</translation>
     </message>
+    <message>
+        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
+        <translation>Standardvy för MythVideo. Andra vyer kan nås genom popup-menyn tillgänglig via MENY-knappen.</translation>
+    </message>
 </context>
 <context>
     <name>ThemeUI</name>
@@ -447,18 +443,6 @@
         <source></source>
         <translation></translation>
     </message>
-    <message>
-        <source>MENU: Options</source>
-        <translation>MENY: Inställningar</translation>
-    </message>
-    <message>
-        <source>Up/Down, Page Up/Down - Browse</source>
-        <translation>Up/Down, Page Up/Down - Bläddra</translation>
-    </message>
-    <message>
-        <source>Menu - Options</source>
-        <translation>Meny - Inställningar</translation>
-    </message>
     <message>
         <source>Parental</source>
         <translation>Barnlås</translation>
@@ -479,13 +463,21 @@
         <source>User Rating</source>
         <translation>Användarbetyg</translation>
     </message>
+    <message>
+        <source>INFO - Action Menu</source>
+        <translation>INFO - Handlingsmeny</translation>
+    </message>
+    <message>
+        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
+        <translation>Upp/Ner, Page Up/Down: Bläddra   MENY: Inställningar   INFO: Handlingsmeny</translation>
+    </message>
+    <message>
+        <source>Play File After This:</source>
+        <translation>Spela fil efter detta:</translation>
+    </message>
 </context>
 <context>
     <name>VideoBrowser</name>
-    <message>
-        <source>Parental Pin:</source>
-        <translation type="obsolete">PIN-kod (barnlås):</translation>
-    </message>
     <message>
         <source>%1 of %2</source>
         <translation>%1 av %2</translation>
@@ -502,14 +494,6 @@
         <source>minutes</source>
         <translation>minuter</translation>
     </message>
-    <message>
-        <source>Ok</source>
-        <translation type="obsolete">OK</translation>
-    </message>
-    <message>
-        <source>Select action</source>
-        <translation type="obsolete">Välj åtgärd</translation>
-    </message>
     <message>
         <source>Watch This Video</source>
         <translation>Spela upp denna film</translation>
@@ -523,8 +507,93 @@
         <translation>Filtervisning</translation>
     </message>
     <message>
-        <source>Switch to Video Listings</source>
-        <translation type="obsolete">Växla till filmlista</translation>
+        <source>Cancel</source>
+        <translation>Avbryt</translation>
+    </message>
+</context>
+<context>
+    <name>VideoDialog</name>
+    <message>
+        <source>Switch to Browse View</source>
+        <translation>Byt till bläddringsläge</translation>
+    </message>
+    <message>
+        <source>Switch to Gallery View</source>
+        <translation>Byt till galleriläge</translation>
+    </message>
+    <message>
+        <source>Switch to List View</source>
+        <translation>Byt till listläge</translation>
+    </message>
+    <message>
+        <source>Select action</source>
+        <translation>Välj åtgärd</translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>OK</translation>
+    </message>
+    <message>
+        <source>Parental Pin:</source>
+        <translation>PIN-kod (barnlås):</translation>
+    </message>
+</context>
+<context>
+    <name>VideoFilterDialog</name>
+    <message>
+        <source>Result of this filter : %1 video(s)</source>
+        <translation>Resultat av detta filter: %1 video(s)</translation>
+    </message>
+    <message>
+        <source>Result of this filter : No Videos</source>
+        <translation>Resultat av detta filter: Inga videos</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>Okänd</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>minuter</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Alla</translation>
+    </message>
+    <message>
+        <source>Save as default</source>
+        <translation>Spara som standard</translation>
+    </message>
+    <message>
+        <source>Done</source>
+        <translation>Klar</translation>
+    </message>
+</context>
+<context>
+    <name>VideoGallery</name>
+    <message>
+        <source>Filter Display</source>
+        <translation>Filtervisning</translation>
+    </message>
+    <message>
+        <source>Watch This Video</source>
+        <translation>Spela upp denna film</translation>
+    </message>
+    <message>
+        <source>View Full Plot</source>
+        <translation>Visa full beskrivning</translation>
+    </message>
+    <message>
+        <source>View Details</source>
+        <translation>Visa detaljer</translation>
+    </message>
+    <message>
+        <source>Plain View</source>
+        <translation>Vanlig vy</translation>
+    </message>
+    <message>
+        <source>Folder View</source>
+        <translation>Katalogvy</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -606,6 +675,17 @@
         <translation>Ta bort denna fil?</translation>
     </message>
 </context>
+<context>
+    <name>VideoSelected</name>
+    <message>
+        <source>No rating available.</source>
+        <translation>Ingen rankning tillgänglig.</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>minuter</translation>
+    </message>
+</context>
 <context>
     <name>VideoTree</name>
     <message>
