@@ -8,22 +8,28 @@
 
 #include "videofilter.h"
 
-VideoFilterSettings::VideoFilterSettings(QSqlDatabase * ldb, bool loaddefaultsettings, bool _allowBrowse)
+VideoFilterSettings::VideoFilterSettings(QSqlDatabase * ldb, bool loaddefaultsettings, const QString& _prefix)
 {
-    
+    if ( !_prefix )
+        prefix = "VideoDefault";
+    else
+        prefix = _prefix + "Default";
     
     // do nothing yet
     db = ldb;
-    if (loaddefaultsettings){
-        category = gContext->GetNumSetting("VideoDefaultCategory",-1);
-        genre = gContext->GetNumSetting("VideoDefaultGenre",-1);
-        country = gContext->GetNumSetting("VideoDefaultCountry",-1);
-        year = gContext->GetNumSetting("VideoDefaultYear",-1);
-        runtime = gContext->GetNumSetting("VideoDefaultRuntime",-2);
-        userrating = gContext->GetNumSetting("VideoDefaultUserrating",-1);
-        browse = gContext->GetNumSetting("VideoDefaultBrowse",-1);
-        orderby = gContext->GetNumSetting("VideoDefaultOrderby",0);
-    }else{
+    if (loaddefaultsettings)
+    {
+        category = gContext->GetNumSetting( QString("%1Category").arg(prefix),-1);
+        genre = gContext->GetNumSetting( QString("%1Genre").arg(prefix),-1);
+        country = gContext->GetNumSetting( QString("%1Country").arg(prefix),-1);
+        year = gContext->GetNumSetting( QString("%1Year").arg(prefix),-1);
+        runtime = gContext->GetNumSetting( QString("%1Runtime").arg(prefix),-2);
+        userrating = gContext->GetNumSetting( QString("%1Userrating").arg(prefix),-1);
+        browse = gContext->GetNumSetting( QString("%1Browse").arg(prefix),-1);
+        orderby = gContext->GetNumSetting( QString("%1Orderby").arg(prefix),0);
+    }
+    else
+    {
         category = -1;
         genre = -1;
         country = -1;
@@ -33,10 +39,6 @@ VideoFilterSettings::VideoFilterSettings(QSqlDatabase * ldb, bool loaddefaultset
         browse = -1;
         orderby = 0;
     }
-    
-    allowBrowse = _allowBrowse;
-    if (!allowBrowse)
-        browse = 1;
 
 }
 
@@ -50,9 +52,8 @@ VideoFilterSettings::VideoFilterSettings(VideoFilterSettings *other)
     runtime = other->runtime;
     userrating = other->userrating;
     browse = other->browse;
-    allowBrowse = other->allowBrowse;
     orderby = other->orderby;
-    db = other->db;
+    prefix = other->prefix;
 }
 
 VideoFilterSettings::~VideoFilterSettings()
@@ -61,14 +62,15 @@ VideoFilterSettings::~VideoFilterSettings()
 }
 void VideoFilterSettings::saveAsDefault()
 {
-    gContext->SaveSetting("VideoDefaultCategory", category);
-    gContext->SaveSetting("VideoDefaultGenre", genre);
-    gContext->SaveSetting("VideoDefaultCountry", country);
-    gContext->SaveSetting("VideoDefaultYear", year);
-    gContext->SaveSetting("VideoDefaultRuntime", runtime);
-    gContext->SaveSetting("VideoDefaultUserrating", userrating);
-    gContext->SaveSetting("VideoDefaultBrowse", browse);
-    gContext->SaveSetting("VideoDefaultOrderby", orderby);
+
+    gContext->SaveSetting(QString("%1Category").arg(prefix), category);
+    gContext->SaveSetting(QString("%1Genre").arg(prefix), genre);
+    gContext->SaveSetting(QString("%1Country").arg(prefix), country);
+    gContext->SaveSetting(QString("%1Year").arg(prefix), year);
+    gContext->SaveSetting(QString("%1Runtime").arg(prefix), runtime);
+    gContext->SaveSetting(QString("%1Userrating").arg(prefix), userrating);
+    gContext->SaveSetting(QString("%1Browse").arg(prefix), browse);
+    gContext->SaveSetting(QString("%1Orderby").arg(prefix), orderby);
 }
 
 VideoFilterDialog::VideoFilterDialog(QSqlDatabase *ldb,
@@ -197,24 +199,14 @@ QString VideoFilterSettings::BuildClauseWhere()
         else 
             where = QString(" WHERE userrating >= %1").arg(userrating);
     }
-    
-    if (allowBrowse)
-    {
-        if (browse !=-1)
-        {
-            if (where)
-                where += QString(" AND browse = %1").arg(browse);
-            else 
-                where = QString(" WHERE browse = %1").arg(browse);
-        } 
-    }
-    else
+
+    if (browse !=-1)
     {
         if (where)
-            where += QString(" AND browse = 1");
+            where += QString(" AND browse = %1").arg(browse);
         else 
-            where = QString(" WHERE browse = 1");
-    }
+            where = QString(" WHERE browse = %1").arg(browse);
+    } 
     
 
     return where;
@@ -242,7 +234,7 @@ void VideoFilterDialog::update_numvideo()
     
     if (numvideos_text)
     {
-        QString select = QString("SELECT * FROM ");
+        QString select = QString("SELECT NULL FROM ");
         QString from = currentSettings->BuildClauseFrom();
         QString where = currentSettings->BuildClauseWhere();
         QString q_string = QString("%1 %2 %3")
@@ -250,11 +242,11 @@ void VideoFilterDialog::update_numvideo()
         
         QSqlQuery a_query(q_string,db);
         
-        if((a_query.isActive()) && (a_query.numRowsAffected()>0))
+        if((a_query.isActive()) && (a_query.size()>0))
         {
             numvideos_text->SetText(
                     QString(tr("Result of this filter : %1 video(s)"))
-                            .arg(a_query.numRowsAffected()));
+                            .arg(a_query.size()));
         }
         else
         {
@@ -272,12 +264,12 @@ void VideoFilterDialog::fillWidgets()
         QString q_string = QString("SELECT intid, category FROM videocategory "
                                    "ORDER BY category");
         QSqlQuery a_query(q_string,db);
-        if (a_query.isActive() && a_query.numRowsAffected()>0)
+        if (a_query.isActive() && a_query.size()>0)
         {
             while (a_query.next())
             {
-                category_select->addItem(a_query.value(0).toInt(),
-                                         a_query.value(1).toString());
+                QString cat = QString::fromUtf8(a_query.value(1).toString());
+                category_select->addItem(a_query.value(0).toInt(), cat);
             }
         }
         category_select->addItem(0,tr("Unknown"));
@@ -288,16 +280,17 @@ void VideoFilterDialog::fillWidgets()
     {
         genre_select->addItem(-1,"All");
         QString q_string = QString("Select intid, genre FROM videogenre "
-                                                "INNER JOIN videometadatagenre "
-                                                "ON intid = idgenre "
-                                                "GROUP BY intid , genre "
-                                                "ORDER BY genre;");
+                                   "INNER JOIN videometadatagenre "
+                                   "ON intid = idgenre "
+                                   "GROUP BY intid , genre "
+                                   "ORDER BY genre;");
         QSqlQuery a_query(q_string,db);
-        if (a_query.isActive()&&a_query.numRowsAffected()>0)
+        if (a_query.isActive() && a_query.size()>0)
         {
             while (a_query.next())
             {
-                genre_select->addItem(a_query.value(0).toInt() ,a_query.value(1).toString());
+                QString genre = QString::fromUtf8(a_query.value(1).toString());
+                genre_select->addItem(a_query.value(0).toInt(), genre);
             }
         }
         genre_select->addItem(0,tr("Unknown"));
@@ -308,16 +301,17 @@ void VideoFilterDialog::fillWidgets()
     {
         country_select->addItem(-1,"All");
         QString q_string = QString("Select intid, country FROM videocountry "
-                                        "INNER JOIN videometadatacountry "
-                                        "ON intid = idcountry "
-                                        "GROUP BY intid, country "
-                                        "ORDER BY country;");
+                                   "INNER JOIN videometadatacountry "
+                                   "ON intid = idcountry "
+                                   "GROUP BY intid, country "
+                                   "ORDER BY country;");
         QSqlQuery a_query(q_string,db);
-        if (a_query.isActive()&&a_query.numRowsAffected()>0)
+        if (a_query.isActive() && a_query.size()>0)
         {
             while(a_query.next())
             {
-                country_select->addItem(a_query.value(0).toInt(),a_query.value(1).toString());
+                QString country = QString::fromUtf8(a_query.value(1).toString());
+                country_select->addItem(a_query.value(0).toInt(), country);
             }
         }
         country_select->addItem(0,tr("Unknown"));
@@ -328,9 +322,9 @@ void VideoFilterDialog::fillWidgets()
     {
         year_select->addItem(-1,"All");
         QString q_string = QString("SELECT year FROM videometadata "
-                                        "GROUP BY year ORDER BY year DESC;");
+                                   "GROUP BY year ORDER BY year DESC;");
         QSqlQuery a_query(q_string, db);
-        if(a_query.isActive()&& a_query.numRowsAffected()>0)
+        if(a_query.isActive() && a_query.size()>0)
         {
             while(a_query.next())
             {
@@ -353,10 +347,10 @@ void VideoFilterDialog::fillWidgets()
     {
         runtime_select->addItem(-2,"All");
         QString q_string = QString("SELECT FLOOR((length-1)/30) "
-                                        "FROM videometadata "
-                                        "GROUP BY FLOOR((length-1)/30);");
+                                   "FROM videometadata "
+                                   "GROUP BY FLOOR((length-1)/30);");
         QSqlQuery a_query(q_string,db);
-        if (a_query.isActive()&&a_query.numRowsAffected()>0)
+        if (a_query.isActive() && a_query.size()>0)
         {
            while (a_query.next())
            {
@@ -381,10 +375,10 @@ void VideoFilterDialog::fillWidgets()
     {
         userrating_select->addItem(-1,tr("All"));
         QString q_string = QString("SELECT FLOOR(userrating) "
-                                        "FROM videometadata "
-                                        "GROUP BY FLOOR(userrating) DESC;");
+                                   "FROM videometadata "
+                                   "GROUP BY FLOOR(userrating) DESC;");
         QSqlQuery a_query(q_string, db);
-        if(a_query.isActive()&&a_query.numRowsAffected()>0)
+        if(a_query.isActive()&&a_query.size()>0)
         {
             while(a_query.next())
             {
@@ -397,19 +391,12 @@ void VideoFilterDialog::fillWidgets()
     
     if (browse_select)
     {
-        if(originalSettings->getAllowBrowse())
-        {
-            browse_select->addItem(-1,"All");
-            browse_select->addItem(1,"Yes");
-            browse_select->addItem(0,"No");
-            browse_select->setToItem(currentSettings->getBrowse());
-        }
-        else
-        {
-            browse_select->addItem(1,"Yes");
-            browse_select->setToItem(currentSettings->getBrowse());
-        }
+        browse_select->addItem(-1,"All");
+        browse_select->addItem(1,"Yes");
+        browse_select->addItem(0,"No");
+        browse_select->setToItem(currentSettings->getBrowse());
     }
+    
     if (orderby_select)
     {
         orderby_select->addItem(0,"title");
@@ -450,7 +437,7 @@ void VideoFilterDialog::keyPressEvent(QKeyEvent *e)
            if ((year_select) && (getCurrentFocusWidget() == year_select)) 
                 currentSelector = year_select;
            if ((runtime_select)&&(getCurrentFocusWidget() == runtime_select))
-                currentSelector = runtime_select;	
+                currentSelector = runtime_select;   
            if ((userrating_select)&&(getCurrentFocusWidget() == userrating_select)) 
                 currentSelector = userrating_select;
             if ((browse_select)&&(getCurrentFocusWidget() == browse_select)) 
