@@ -18,6 +18,7 @@ FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 #include <qpixmap.h>
 #include <unistd.h>
 
+#include <cmath>
 using namespace std;
 
 #include "metadata.h"
@@ -78,6 +79,33 @@ void VideoGallery::keyPressEvent(QKeyEvent *e)
 {
     bool handled = false;
     QStringList actions;
+    
+    gContext->GetMainWindow()->TranslateKeyPress("Global", e, actions);
+    for (unsigned int i = 0; i < actions.size() && !handled; i++)
+    {
+        QString action = actions[i];
+        
+
+        if (action == "SELECT")
+        {
+            handled = true;
+            handled = handleSelect();
+        }
+        else if ( (action == "UP")  || (action == "DOWN") ||
+                  (action == "LEFT") ||(action == "RIGHT") ||
+                  (action == "PAGEUP") || (action == "PAGEDOWN"))
+        {
+            handled = true;
+            moveCursor(action);
+        }
+        else if (action == "1" || action == "2" ||
+                 action == "3" || action == "4")
+        {
+            handled = true;
+            setParentalLevel(action.toInt());        // parental control
+        }
+    }    
+    
     gContext->GetMainWindow()->TranslateKeyPress("Video", e, actions);
 
     for (unsigned int i = 0; i < actions.size() && !handled; i++)
@@ -89,17 +117,6 @@ void VideoGallery::keyPressEvent(QKeyEvent *e)
         {
             handled = handleSelect();
         }
-        else if ( (action == "UP")  || (action == "DOWN") ||
-                  (action == "LEFT") ||(action == "RIGHT") ||
-                  (action == "PAGEUP") || (action == "PAGEDOWN"))
-        {
-             moveCursor(action);
-        }
-        else if (action == "1" || action == "2" ||
-                 action == "3" || action == "4")
-        {
-            setParentalLevel(action.toInt());        // parental control
-        }
         else if (action == "FILTER")
         {
             slotDoFilter();
@@ -112,6 +129,10 @@ void VideoGallery::keyPressEvent(QKeyEvent *e)
                 doMenu(true);
             }
         }
+        else if (action == "INCPARENT")
+            shiftParental(1);
+        else if (action == "DECPARENT")
+            shiftParental(-1);            
         else if (action == "MENU")
         {
             doMenu(false);
@@ -125,6 +146,21 @@ void VideoGallery::keyPressEvent(QKeyEvent *e)
     }
 
     if (!handled)
+    {
+        gContext->GetMainWindow()->TranslateKeyPress("TV Frontend", e, actions);
+
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
+        {
+            QString action = actions[i];
+            if (action == "PLAYBACK")
+            {
+                handled = true;
+                slotWatchVideo();
+            }
+        }            
+    }
+    
+    if (!handled)        
         MythDialog::keyPressEvent(e);
 }
 
