@@ -35,12 +35,13 @@ VideoManager::VideoManager(QSqlDatabase *ldb,
 
     expectingPopup = false;
     popup = NULL;
-    
-
-    currentVideoFilter = new VideoFilterSettings(db,false);
+    videoDir = gContext->GetSetting("VideoStartupDir");    
+    artDir = gContext->GetSetting("VideoArtworkDir");
+    currentVideoFilter = new VideoFilterSettings(db, true, "VideoManager");
     RefreshMovieList();
-
-    fullRect = QRect(0, 0, (int)(800*wmult), (int)(600*hmult));
+    
+    fullRect = QRect(0, 0, size().width(), size().height());
+    
 
     noUpdate = false;
     curIMDBNum = "";
@@ -58,7 +59,7 @@ VideoManager::VideoManager(QSqlDatabase *ldb,
     inDataMovie = 0;
     listCountMovie = 0;
     dataCountMovie = 0;
-
+    
     m_state = SHOWING_MAINWINDOW;
 
     theme = new XMLParse();
@@ -191,15 +192,14 @@ void VideoManager::RefreshMovieList()
     updateML = true;
     m_list.clear();
 
-//    QSqlQuery query("SELECT intid FROM videometadata ORDER BY title;", db);
     QString thequery = QString("SELECT intid FROM %1 %2 %3")
                                .arg(currentVideoFilter->BuildClauseFrom())
                                .arg(currentVideoFilter->BuildClauseWhere())
                                .arg(currentVideoFilter->BuildClauseOrderBy());
-   QSqlQuery query(thequery,db);
+    QSqlQuery query(thequery,db);
     Metadata *myData;
 
-    if (query.isActive() && query.numRowsAffected() > 0)
+    if (query.isActive() && query.size() > 0)
     {
         while (query.next())
         {
@@ -378,7 +378,7 @@ void VideoManager::copyFinished(QNetworkOperation* op) {
       case QNetworkProtocol::StStopped:
          state = "The operation has been processed but has been stopped before it finished, and is waiting to be processed.";
          break;
-      default: state = "Uknown"; break;
+      default: state = "Unknown"; break;
    }
    VERBOSE(VB_ALL, QString("%1: %2: %3")
            .arg(operation)
@@ -415,42 +415,42 @@ void VideoManager::GetMovieData(QString movieNum)
         curitem->setUserRating(data["UserRating"].toFloat());
         curitem->setRating(data["MovieRating"]);
         curitem->setLength(data["Runtime"].toInt());
-	//movieGenres
-	movieGenres.clear();
-	QString genres = data["Genres"];
-	int indice ;
-	QString genre;
-	while (genres!= ""){
-		indice = genres.find(",");
-		if (indice == -1){
-			genre = genres;
-			genres = "";
-		} else {
-			genre = genres.left(indice);
-			genres = genres.right(genres.length()-indice -1);
-		}
-		movieGenres.append(genre.stripWhiteSpace());
-	}
-	curitem->setGenres(movieGenres);
-	//movieCountries
-	movieCountries.clear();
-	QString countries = data["Countries"];
-	QString country;
-	while (countries!= ""){
-		indice = countries.find(",");
-		if (indice == -1){
-			country = countries;
-			countries = "";
-		} else {
-			country = countries.left(indice);
-			countries = countries.right(countries.length()-indice -1);
-		}
-		country.stripWhiteSpace();
+    //movieGenres
+    movieGenres.clear();
+    QString genres = data["Genres"];
+    int indice ;
+    QString genre;
+    while (genres!= ""){
+        indice = genres.find(",");
+        if (indice == -1){
+            genre = genres;
+            genres = "";
+        } else {
+            genre = genres.left(indice);
+            genres = genres.right(genres.length()-indice -1);
+        }
+        movieGenres.append(genre.stripWhiteSpace());
+    }
+    curitem->setGenres(movieGenres);
+    //movieCountries
+    movieCountries.clear();
+    QString countries = data["Countries"];
+    QString country;
+    while (countries!= ""){
+        indice = countries.find(",");
+        if (indice == -1){
+            country = countries;
+            countries = "";
+        } else {
+            country = countries.left(indice);
+            countries = countries.right(countries.length()-indice -1);
+        }
+        country.stripWhiteSpace();
 
-		movieCountries.append(country.stripWhiteSpace());
-	}
-	curitem->setCountries(movieCountries);
-	
+        movieCountries.append(country.stripWhiteSpace());
+    }
+    curitem->setCountries(movieCountries);
+    
         curitem->setInetRef(movieNumber);
         QString movieCoverFile = "";
         movieCoverFile = GetMoviePoster(movieNumber);
@@ -505,7 +505,7 @@ QString VideoManager::executeExternal(QStringList args, QString purpose)
        }
     } else {
        err = QString("\"%1\" failed: Could not start process")
-		.arg(cmd.local8Bit());
+        .arg(cmd.local8Bit());
     }
 
     while (proc.canReadLineStdout() || proc.canReadLineStderr()) {
@@ -867,7 +867,10 @@ void VideoManager::updateInfo(QPainter *p)
 
            type = (UITextType *)container->GetType("filename");
            if (type)
-               type->SetText(filename);
+           {
+                filename.remove(videoDir + "/");
+                type->SetText(filename);
+           }
 
            type = (UITextType *)container->GetType("director");
            if (type)
@@ -879,8 +882,11 @@ void VideoManager::updateInfo(QPainter *p)
 
            type = (UITextType *)container->GetType("coverfile");
            if (type)
+           {
+               coverfile.remove(artDir + "/");
                type->SetText(coverfile);
-
+           }
+           
            type = (UITextType *)container->GetType("inetref");
            if (type)
                type->SetText(inetref);
@@ -998,6 +1004,9 @@ void VideoManager::exitWin()
 
 void VideoManager::doParental(int amount)
 {
+    if (!curitem)
+        return;
+
     int curshowlevel = curitem->ShowLevel();
 
     curshowlevel += amount;
@@ -1333,6 +1342,9 @@ void VideoManager::pageUp()
 
 void VideoManager::videoMenu()
 {
+    if (!curitem)
+        return;
+
     popup = new MythPopupBox(gContext->GetMainWindow(), "video popup");
 
     expectingPopup = true;
@@ -1340,19 +1352,27 @@ void VideoManager::videoMenu()
     popup->addLabel(tr("Select action:"));
     popup->addLabel("");
 
-    QButton *editButton = popup->addButton(tr("Edit Metadata"), this, SLOT(slotEditMeta()));
+    QButton *editButton = NULL;
+    if (curitem)
+    {
+        editButton = popup->addButton(tr("Edit Metadata"), this, SLOT(slotEditMeta()));
 
-    popup->addButton(tr("Search IMDB"), this, SLOT(slotAutoIMDB()));    
-    popup->addButton(tr("Manually Enter IMDB #"), this, SLOT(slotManualIMDB()));
-    popup->addButton(tr("Reset Metadata"), this, SLOT(slotResetMeta()));
-    popup->addButton(tr("Toggle Browseable"), this, SLOT(slotToggleBrowseable()));
-    popup->addButton(tr("Remove Video"), this, SLOT(slotRemoveVideo()));
-    popup->addButton(tr("Filter Display"), this, SLOT(slotDoFilter()));
+        popup->addButton(tr("Search IMDB"), this, SLOT(slotAutoIMDB()));    
+        popup->addButton(tr("Manually Enter IMDB #"), this, SLOT(slotManualIMDB()));
+        popup->addButton(tr("Reset Metadata"), this, SLOT(slotResetMeta()));
+        popup->addButton(tr("Toggle Browseable"), this, SLOT(slotToggleBrowseable()));
+        popup->addButton(tr("Remove Video"), this, SLOT(slotRemoveVideo()));
+    }
+
+    QButton *filterButton = popup->addButton(tr("Filter Display"), this, SLOT(slotDoFilter()));
     popup->addButton(tr("Cancel"), this, SLOT(slotDoCancel()));
 
     popup->ShowPopup(this, SLOT(slotDoCancel()));
     
-    editButton->setFocus();    
+    if (editButton)
+        editButton->setFocus();    
+    else 
+        filterButton->setFocus();
 }
 
 
@@ -1598,6 +1618,9 @@ void VideoManager::slotAutoIMDB()
 
 void VideoManager::slotEditMeta()
 {
+    if (!curitem)
+        return;
+        
     EditMetadataDialog* md_editor = new EditMetadataDialog(db, curitem, gContext->GetMainWindow(),
                                                            "edit_metadata", "video-",
                                                            "edit metadata dialog");
@@ -1615,7 +1638,7 @@ void VideoManager::slotEditMeta()
 void VideoManager::slotRemoveVideo()
 {
     cancelPopup();
-    if (m_state == SHOWING_MAINWINDOW)
+    if (curitem && m_state == SHOWING_MAINWINDOW)
     {
         bool okcancel;
         MythPopupBox * ConfirmationDialog = new MythPopupBox (gContext->GetMainWindow());
@@ -1702,10 +1725,17 @@ void VideoManager::slotDoFilter()
 
 void VideoManager::slotToggleBrowseable()
 {
+    if (!curitem)
+        return;
+
     cancelPopup();
-    
-    curitem->setBrowse(!curitem->Browse());
-    curitem->updateDatabase(db);
+   
+    if (curitem)
+    { 
+        curitem->setBrowse(!curitem->Browse());
+        curitem->updateDatabase(db);
+    }
+
     RefreshMovieList();
     update(infoRect);
 }
