@@ -14,6 +14,7 @@ using namespace std;
 #include <mythtv/util.h>
 #include <mythtv/mythmedia.h>
 #include <mythtv/mythmediamonitor.h>
+#include <mythtv/mythdbcon.h>
 
 #include "videofilter.h"
 const long WATCHED_WATERMARK = 10000; // Less than this and the chain of videos will 
@@ -42,7 +43,7 @@ VideoTree::VideoTree(MythMainWindow *parent, QSqlDatabase *ldb,
     wireUpTheme();
     video_tree_root = new GenericTree("video root", -2, false);
     
-    currentVideoFilter = new VideoFilterSettings(db, true);
+    currentVideoFilter = new VideoFilterSettings(db, true, "VideoTree");
     
     buildVideoList();
     
@@ -110,6 +111,23 @@ void VideoTree::keyPressEvent(QKeyEvent *e)
             handled = false;
     }
 
+        if (!handled)
+    {
+    
+    gContext->GetMainWindow()->TranslateKeyPress("TV Frontend", e, actions);
+
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
+        {
+            QString action = actions[i];
+            if (action == "PLAYBACK")
+            {
+                handled = true;
+                playVideo(-1);
+            }
+        }            
+    }
+
+    
     if (!handled) 
         MythThemedDialog::keyPressEvent(e);
 }
@@ -219,14 +237,13 @@ void VideoTree::setParentalLevel(int which_level)
 
 bool VideoTree::ignoreExtension(QString extension)
 {
-    QString q_string = QString("SELECT f_ignore FROM videotypes WHERE extension = \"%1\" ;")
-                              .arg(extension);
-
-    QSqlQuery a_query(q_string, db);
-    if(a_query.isActive() && a_query.numRowsAffected() > 0)
+    MSqlQuery query(QString::null, db);
+    query.prepare("SELECT f_ignore FROM videotypes WHERE extension = :EXT ;");
+    query.bindValue(":EXT", extension);
+    if(query.exec() && query.isActive() && query.size() > 0)
     {
-        a_query.next();
-        return a_query.value(0).toBool();
+        query.next();
+        return query.value(0).toBool();
     }
     
     return !gContext->GetNumSetting("VideoListUnknownFileTypes", 1);
@@ -400,7 +417,7 @@ void VideoTree::buildVideoList()
                     .arg(currentVideoFilter->BuildClauseWhere())
                     .arg(currentVideoFilter->BuildClauseOrderBy());
         
-        QSqlQuery query(thequery,db);
+        MSqlQuery query(thequery,db);
         Metadata *myData;
         if (!video_tree_data)
             video_tree_data = video_tree_root->addNode("videos", -2, false);
@@ -409,7 +426,7 @@ void VideoTree::buildVideoList()
         {
             cerr << "videotree.o: Your database sucks" << endl;
         }
-        else if (query.numRowsAffected() > 0)
+        else if (query.size() > 0)
         {
             QString prefix = gContext->GetSetting("VideoStartupDir");
             if(prefix.length() < 1)
@@ -507,27 +524,30 @@ void VideoTree::handleTreeListEntry(int node_int, IntVector*)
                 QString the_file = *(browser_mode_files.at(node_int));
                 QString base_name = the_file.section("/", -1);
 
-		/* See if we can find this filename in DB */
+                /* See if we can find this filename in DB */
                 curitem->setFilename(the_file);
-                if(curitem->fillDataFromFilename(db)) {
-		    video_title->SetText(curitem->Title());
+                
+                if(curitem->fillDataFromFilename(db)) 
+                {
+                    video_title->SetText(curitem->Title());
                     video_file->SetText(curitem->Filename().section("/", -1));
                     video_poster->SetImage(curitem->CoverFile());
                     video_poster->LoadImage();
                     if (video_plot)
                         video_plot->SetText(curitem->Plot());
-		}
-		else
-		{
+                }
+                else
+                {
                     /* Nope, let's make the best of the situation */
-		    video_title->SetText(base_name.section(".", 0, -2));
+                    video_title->SetText(base_name.section(".", 0, -2));
                     video_file->SetText(base_name);
-		    video_poster->ResetImage();
+                    video_poster->ResetImage();
                     curitem->setTitle(base_name.section(".", 0, -2));
                     curitem->setPlayer(player);
                     if (video_plot)
                         video_plot->SetText(" ");
-		}
+                }
+                
                 extension = the_file.section(".", -1);
                 player = gContext->GetSetting("VideoDefaultPlayer");
                 
@@ -566,23 +586,21 @@ void VideoTree::handleTreeListEntry(int node_int, IntVector*)
         //
         
 
+        MSqlQuery query(QString::null, db);
+        query.prepare("SELECT playcommand, use_default FROM "
+                      "videotypes WHERE extension = :EXT ;");
+        query.bindValue(":EXT", extension);
 
-        QString q_string = QString("SELECT playcommand, use_default FROM "
-                                   "videotypes WHERE extension = \"%1\" ;")
-                                   .arg(extension);
-
-        QSqlQuery a_query(q_string, db);
-        
-        if(a_query.isActive() && a_query.numRowsAffected() > 0)
+        if(query.exec() && query.isActive() && query.size() > 0)
         {
-            a_query.next();
-            if(!a_query.value(1).toBool() && unique_player.length() < 1)
+            query.next();
+            if(!query.value(1).toBool() && unique_player.length() < 1)
             {
                 //
                 //  This file type is defined and
                 //  it is not set to use default player
                 //
-                player = a_query.value(0).toString();                
+                player = query.value(0).toString();                
             }
         }
 
@@ -901,7 +919,7 @@ void VideoTree::playVideo(Metadata *someItem)
         if (parentItem->ChildID() > 0)
         {
             //Load up data about this child
-            command = getCommand(someItem);
+            command = getCommand(childItem);
             playing_time.start();
             myth_system((QString("%1 ") .arg(command)).local8Bit());
         }
@@ -953,23 +971,22 @@ QString VideoTree::getHandler(Metadata *someItem)
         
         QString extension = filename.section(".", -1, -1);
 
-        QString q_string = QString("SELECT playcommand, use_default FROM "
-                                   "videotypes WHERE extension = \"%1\" ;")
-                                   .arg(extension);
+        MSqlQuery query(QString::null, db);
+        query.prepare("SELECT playcommand, use_default FROM "
+                      "videotypes WHERE extension = :EXT ;");
+        query.bindValue(":EXT", extension);
 
-        QSqlQuery a_query(q_string, db);
-    
-        if(a_query.isActive() && a_query.numRowsAffected() > 0)
+        if(query.exec() && query.isActive() && query.size() > 0)
         {
-            a_query.next();
-            if(!a_query.value(1).toBool())
+            query.next();
+            if(!query.value(1).toBool())
             {
                 //
                 //  This file type is defined and
                 //  it is not set to use default player
                 //
 
-                handler = a_query.value(0).toString();                
+                handler = query.value(0).toString();                
             }
         }
     }
